"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var cli_1 = require("./cli");
describe("buildRuns", function () {
    test("creates runs object without summary if run not complete", function () {
        var startTime = new Date();
        var run = {
            name: "Log in",
            status: "runs",
            startTime: startTime,
            steps: []
        };
        var runs = cli_1.buildRuns(run);
        expect(runs).toMatchObject({
            runs: [run],
            summary: null
        });
    });
    test("creates runs object with passing summary if run passed", function () {
        var startTime = new Date();
        var run = {
            name: "Log in",
            status: "pass",
            startTime: startTime,
            steps: []
        };
        var runs = cli_1.buildRuns(run);
        expect(runs).toMatchObject({
            runs: [run],
            summary: { fail: 0, pass: 1, total: 1 }
        });
    });
    test("creates runs object with failing summary if run failed", function () {
        var startTime = new Date();
        var run = {
            name: "Log in",
            status: "fail",
            startTime: startTime,
            steps: []
        };
        var runs = cli_1.buildRuns(run);
        expect(runs).toMatchObject({
            runs: [run],
            summary: { fail: 1, pass: 0, total: 1 }
        });
    });
});
describe("createRunFromJob", function () {
    test("creates run object from job", function () {
        var steps = [
            {
                locator: {
                    inputType: "text",
                    name: "username",
                    tagName: "input",
                    xpath: '//*[@id="username"]'
                },
                type: "type",
                value: "spirit"
            },
            {
                locator: {
                    inputType: "password",
                    name: "password",
                    tagName: "input",
                    xpath: '//*[@id="password"]'
                },
                type: "type",
                value: "supersecret"
            },
            {
                locator: {
                    tagName: "button",
                    textContent: "login",
                    xpath: '//*[@id="login"]/button'
                },
                type: "click"
            }
        ];
        var job = {
            name: "Log in",
            steps: steps,
            url: "url"
        };
        var run = cli_1.createRunFromJob(job);
        expect(run).toMatchObject({
            status: "queued",
            steps: [
                {
                    name: "enter spirit into username input[type='text']",
                    status: "queued"
                },
                {
                    name: "enter supersecret into password input[type='password']",
                    status: "queued"
                },
                {
                    name: "click login button",
                    status: "queued"
                }
            ],
            name: "Log in"
        });
        expect(run.startTime).toBeTruthy();
    });
});
describe("formatStep", function () {
    test("formats click on link step", function () {
        var step = {
            locator: {
                tagName: "a",
                textContent: "contact"
            },
            type: "click"
        };
        var formattedStep = cli_1.formatStep(step);
        expect(formattedStep).toEqual({
            name: "click contact link",
            status: "queued"
        });
    });
    test("formats click on submit input step", function () {
        var step = {
            locator: {
                inputType: "submit",
                name: "signin",
                tagName: "input",
                textContent: "sign in"
            },
            type: "click"
        };
        var formattedStep = cli_1.formatStep(step);
        expect(formattedStep).toEqual({
            name: "click sign in input[type='submit']",
            status: "queued"
        });
    });
    test("formats type into text input", function () {
        var step = {
            locator: {
                id: "input1",
                inputType: "text",
                labels: ["username"],
                name: "user",
                placeholder: "Jane Doe",
                tagName: "input"
            },
            type: "type",
            value: "spirit"
        };
        var formattedStep = cli_1.formatStep(step);
        expect(formattedStep).toEqual({
            name: "enter spirit into username input[type='text']",
            status: "queued"
        });
    });
    test("formats type into password input", function () {
        var step = {
            locator: {
                id: "input2",
                inputType: "password",
                placeholder: "secret",
                tagName: "input"
            },
            type: "type",
            value: "supersecret"
        };
        var formattedStep = cli_1.formatStep(step);
        expect(formattedStep).toEqual({
            name: "enter supersecret into secret input[type='password']",
            status: "queued"
        });
    });
});
//# sourceMappingURL=cli.test.js.map